 /*
  * Copyright (C), 2018-2022
  * Project: starter
  * FileName: SheetPDFExporter
  * Author:   xx
  * Date:     2022/4/29 16:25
  */
 package com.fr.plugin.hd.export;

 import com.fanruan.api.i18n.I18nKit;
 import com.fanruan.api.log.LogKit;
 import com.fr.io.exporter.PDFExporter;
 import com.fr.main.workbook.ResultWorkBook;
 import com.fr.page.PageSetCreator;
 import com.fr.plugin.context.PluginContexts;
 import com.fr.stable.ArrayUtils;
 import com.fr.web.core.ReportRepositoryDeal;

 import java.io.OutputStream;
 import java.util.Arrays;
 import java.util.Map;

 /**
  * <Function Description><br>
  * <SheetPDFExporter>
  *
  * @author xx
  * @since 1.0.0
  */
 public class SheetPDFExporter extends PDFExporter {

     public static final String USEFUL_SHEETS = "usefulSheets";

     private int[] getUsefulSheets(Map<String, Object> reportParameterMap) {
         if (!reportParameterMap.containsKey(USEFUL_SHEETS)) {
             return null;
         }
         String usefulSheets = reportParameterMap.get(USEFUL_SHEETS).toString();
         LogKit.info("hd-SheetPDFExporter-getUsefulSheets-usefulSheets:{}", usefulSheets);
         return Arrays.stream(usefulSheets.split(",")).mapToInt(Integer::parseInt).toArray();
     }

     @Override
     public void export(OutputStream outputStream, ResultWorkBook resultWorkBook, PageSetCreator pageSetCreator, ReportRepositoryDeal reportRepositoryDeal, int[] ints) throws Exception {
         if (PluginContexts.currentContext() == null || !PluginContexts.currentContext().isAvailable()) {
             LogKit.error(I18nKit.getLocText("Plugin-hd_Licence_Expired"));
             super.export(outputStream, resultWorkBook);
             return;
         }
         if (ints == null || ArrayUtils.getLength(ints) <= 0) {
             ints = getUsefulSheets(reportRepositoryDeal.getReportParameterMap());
         }
         ResultWorkBook useResultWorkBook = this.removeUselessSheet(resultWorkBook, ints, resultWorkBook);
         super.export(outputStream, useResultWorkBook);
     }

     @Override
     public void export(OutputStream outputStream, ResultWorkBook resultWorkBook) throws Exception {
         if (PluginContexts.currentContext() == null || !PluginContexts.currentContext().isAvailable()) {
             LogKit.error(I18nKit.getLocText("Plugin-hd_Licence_Expired"));
             super.export(outputStream, resultWorkBook);
             return;
         }
         int[] ints = getUsefulSheets(resultWorkBook.getExecuteParameters());
         ResultWorkBook useResultWorkBook = this.removeUselessSheet(resultWorkBook, ints, resultWorkBook);
         super.export(outputStream, useResultWorkBook);
     }

     private ResultWorkBook removeUselessSheet(ResultWorkBook resultWorkBook, int[] sheetIndexArray, ResultWorkBook handledResultWorkBook) {
         if (ArrayUtils.isEmpty(sheetIndexArray)) {
             return handledResultWorkBook;
         }
         if (resultWorkBook.getReportCount() > sheetIndexArray.length) {
             try {
                 handledResultWorkBook = (ResultWorkBook) resultWorkBook.clone();
                 for (int i = 0; i < resultWorkBook.getReportCount(); i++) {
                     if (!ArrayUtils.contains(sheetIndexArray, i)) {
                         handledResultWorkBook.removeReport(i);
                     }
                 }
             } catch (Exception e) {
                 LogKit.error(e.getMessage(), e);
             }
         }
         return handledResultWorkBook;
     }
 }